
;+ ***********************************************************************
; NAME:
;	CALCFLUX
;
; PURPOSE:
;	PROCEDURE DE CALCUL DE LA DENSITE DE FLUX 
; DES IMAGES EN FONCTION DU TEMPS PROVENANT DE LA FONCTION LEC1D (IMAGE 1D DU
; RH)	
;
; CATEGORY:
;	NRH1 Calculs
;
; CALLING SEQUENCE:
;	CALCFLUX, Tab, Unit, temps, flux
;
; INPUTS:
;                 TAB ...... Tableau issu de LEC1D contenant les images
;                                  (2 dimensions) 
;                           TAB(Espace,Temps)
;                                  (3 Dim sinon )
;                           X(Espace,Temps,type)
;                                               type = 0 ---> Intensite
;                                               type = 1 ---> Polarisation
;                 UNIT ......Numero d'unite logique dont TAB est issu.
;	
; KEYWORD PARAMETERS:
;	HEURES	Tableau d'heures de debut, de fin, chaines de caracteres
;				['hh:mn:ss:ccc','hh:mn:ss:ccc'] 
;	CANAUX	Tableau de canaux de debut et fin du calcul [Deb, Fin]
;
; OUTPUTS:
;	TEMPS .........tableau de temps [ms]
;	FLUX  .........tableau densites de flux I (flux(*,0))
;					et - si disponible dans TAB - 
;					V (flux(*,1))
;
; COMMON BLOCKS:
;	NRH1_GLOBAL
;
; MODIFICATION HISTORY: (bonmartin@obspm.fr)
;	23/11/98	Adapte du logiciel XHELIO
;-*******************************************************************

PRO calcflux, x, lun, HEURES=heures, CANAUX=canaux, temps, flux

;* -------------------------------------------- *
;*     Declaration des variables globales       *
;* -------------------------------------------- *
;
   COMMON NRH1_GLOBAL,nomfich,FichInfo
;
;* ----------------------------------------------------------- *
;*	Test de validite de la syntaxe de la procedure         *
;* ----------------------------------------------------------- *
;
  IF (N_PARAMS() LE 1) THEN BEGIN
      Print, 'Erreur de syntaxe: Parametres manquants'
      Print, ''
      Print, " Syntaxe: CALCFLUX, tableau d'images, no. unite logique, "
      Print, "                [[heure de depart, heure de fin]], " 
      Print, "	              [[canal de depart, canal de fin]], "
      Print, "                tableau temps (sortie), tableau flux (sortie)"
      MESSAGE,' Erreur.'
  ENDIF


;* ----------------------------------------------------------------------- * 
;*	Memorisation de la taille du tableau; controle de la presence de V *
;* ------------------------------------------------------------------------* 
;*
s = size(x)   

IF ((s(0) LT 2) OR (s(0) GT 3)) THEN BEGIN
        Print,['Taille du tableau incompatible',$
                'Le tableau traite doit provenir',$
                'de la fonction LEC1D']
        return
ENDIF

;
;* ------------------------------------------------------------- * 
;*	gestion de l'intervalle de temps de visualisation        *
;* --------------------------------------------------------------*
file=Fichinfo(lun)

; test

verif_heures, file, HEURES=heures, numix1, numix2

;-----------------------------------------------------
; VERIFICATION DES PARAMETRES canaux

verif_canaux, file, CANAUX=canaux, icandeb, icanfin

;* ---------------------------------------------------------------- *
;*	Calcul de l'indice de la premiere et derniere images        *
;*	corespondant a l'intervalle de temps demande ainsi          *
;*	que le temps exact de debut et de fin de l'intervalle       *
;* ---------------------------------------------------------------- *
; 


IF numix2 GT (SIZE(x))(2)-1 THEN numix2 = (SIZE(x))(2)-1

;-----------------------------------------------------
; recuperation du tableau contenant les images demandees 
; seulement

tx = x(*,numix1:numix2,*)

xx = tx(icandeb:icanfin,*,*)
tx = 0.		; Liberation place memoire

; Calcul du tableau de flux : flux(0) = flux I, flux(1) = flux V

flux = TOTAL(xx, 1)*file.paspix(0)	;  somme canaux icandeb a icanfin
	; Pas temporel entre deux images
temps = hms(heures(0)) + FINDGEN(numix2-numix1)*file.paspix(1)	; tableau de temps


 END








