
;+ ***********************************************************************
; NAME:
;	NRH_FLUXASCI
;
; PURPOSE:
;	Cette procedure transforme un fichier dde flux FITS en fichier ASCII
;
; CATEGORY:
;	Fichiers FLUX
;
; CALLING SEQUENCE:
;	NRH_FLUXASCI, FITS, FASCII
;
; INPUTS:
;	FITS	Fichier FITS contenant des flux
;
;	FASCI	Fichier ASCIi a ecrire
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;
; COMMON BLOCKS:
;
; PROCEDURE:
;	Cette procedure ecrit les flux et le temps dans 2 colonnes
;	Si le fichier ASCII existe deja le nouveau traitement est rajoute 
;	a la fin du fichier
;	La date, la frequence, les limites de calcul sont indiques au
;	debut de chaque ta bleau de flux
;
; EXAMPLE:
;	
;
; MODIFICATION HISTORY:
;	Ecrit par:J Bonmartin le 11/08/98 (obspm.fr)
;		le 26/04/01 Rajoute GROUP (JB)
;-*******************************************************************

PRO NRH_FLUXASCI, FFLUX, FASCI, GROUP=Group

IF NOT KEYWORD_SET(GROUP) THEN Group=0

	R=  FINDFILE (Fflux)
	IF R(0) EQ '' THEN BEGIN
		M= WIDGET_MESSAGE('File '+Fflux+'no exist', $
			DIALOG_PARENT=Group)
	RETURN & END

	NX = CW_XTD_NRHF ( Fflux, GROUP=Group)
	H0 = HEADFITS (Fflux)
		DATE = FXPAR(H0,'DATE-OBS')	
	VAL = MRDFITS( Fflux, Nx, Header,/SILENT)
  
	GET_LUN, Unit
	R= FINDFILE (Fasci)
	IF R(0) EQ '' THEN OPENW, Unit, Fasci $
		ELSE OPENU, UNIT, Fasci, /APPEND

	FREQ = STRCOMPRESS (STRING(FXPAR(Header,'FREQ'),FORMAT='(F5.1)'), $
				/REMOVE_ALL)
	Xd = STRCOMPRESS (STRING(FXPAR(Header,'XLIML'),FORMAT='(I3)'), $
				/REMOVE_ALL)
	Xf = STRCOMPRESS (STRING(FXPAR(Header,'XLIMH'),FORMAT='(I3)'), $
				/REMOVE_ALL)
	Yd = STRCOMPRESS (STRING(FXPAR(Header,'YLIML'),FORMAT='(I3)'), $
				/REMOVE_ALL)
	Yf = STRCOMPRESS (STRING(FXPAR(Header,'YLIMH'),FORMAT='(I3)'), $
				/REMOVE_ALL)

	PRINTF, Unit, 'Date: '+Date+' Freq: '+Freq+'MHz '+$
		';Region, X='+Xd+','+Xf+', Y='+Yd+','+Yf

	SZ= SIZE(Val.flux)

	FOR I = 0, Sz(1)-1 DO $
		PRINTF, UNIT, VAL.flux(i),'    ',MSH(VAL.time(i))

	FREE_LUN, Unit

END