
;+ ***********************************************************************
; NAME:
;	CRE_LABELNRH
;
; PURPOSE:
;	Cette fonction cree une chaine servant pour la visualisation des 
;	donnees du NRH. Le contenu de la chaine retournee depend des 
;	indications fournies dans STR_LABEL
;
; CATEGORY:
;	Visualisation NRH
;
; CALLING SEQUENCE:
;	Label = CRE_LABELNRH( Image, Str_im, str_label)
;
; INPUTS:
;	IMAGE	Donnees correspondant a la lecture d'images FITS de  NRH2
;
;	STR_IM	Structure contenant Date, frequence, Heure, Instrument,
;		Parametre, par exemple STR_IM
;
;	STR_LABEL stucture contenant les indications pour constituer le
;		label voir CW_LABELNRH.PRO.
;		  Cette structure contient les champs
;			FREE, DATE, HEURE, FREQ
;		Si les champs date, heure, freq, sont a 1 les valeurs 
;		correspondantes sont introduites dans LABEL. Le champ 
;		FREE permet d'entrer un texte

; KEYWORD PARAMETERS:
;
; OUTPUTS:
;	LABEL	chaine de caracteres
;
;
; RESTRICTIONS:
;	Cette fonction ne peut etre appelee qu'apres CW_LABELNRH qui cree
;	la structutre STR_LABEL, ou apres avoir cree cette stucture
;
; PROCEDURE:
;
; EXAMPLE:
;	Image = MRDFITS('File',1, Header,RANGE={10,10])
;	STR_LABEL = CW_LABELNRH()
;	LABEL = CRE_LABELNRH(Image, Header, Str_label)
;		La chaine LABEL contientles indications choisies dans
;	Cw_labelnrh
; 
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin le 04/03/98 (bonmartin@obspm.fr)
;-*******************************************************************

FUNCTION CRE_LABELNRH, Str, str_label

LFREQ = ''
LDATE= ''
LHR= ''
LINSTR= ''
LPHYS= ''

IF Str_label.Date EQ 1 THEN Ldate = Str.Date

IF Str_label.freq EQ 1 THEN Lfreq = Str.Freq

IF Str_label.heure EQ 1 THEN Lhr = Str.Time

IF Str_label.instrume EQ 1 THEN Linstr = Str.Instrume

IF Str_label.Physpar EQ 1 THEN Lphys = Str.Physpar

Label = str_label.free+' '+Linstr+' '+Lphys+' '+lfreq+' '+ldate+' '+lhr

RETURN, Label

END

;+ ***********************************************************************
; NAME:
;	LABELNRH
;
; PURPOSE:
;	Cette fonction appelle CW_LABELNRH pour definir le contenu du
;	label a afficher sur une image, et CRE_LABELNRH pour creer le
;	label
;
; CATEGORY:
;	Visualisation NRH
;
; CALLING SEQUENCE:
;	Label = LABELNRH( Image, Header)

; INPUTS:
;	IMAGE	Donnees correspondant a la lecture d'images FITS de  NRH2
;
;	HEADER	Header du fichier traite
;
; KEYWORD PARAMETERS:
;	GROUP	Identifieur du widget appelant
;
; OUTPUTS:
;	LABEL	chaine contenant le label
;
; COMMON BLOCKS:
;
; PROCEDURE:
;
; EXAMPLE:
;	Image = MRDFITS('File', 1, Header, RANGE+(20,20)
;	Label LABELNRH( Image, Header)
;		ou bien
;	Label LABELNRH( Image, Header, GROUP=event.top)
;		pour l'appel dans un traitement d'evenement
;
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin le 04/03/98
;-*******************************************************************

FUNCTION LABELNRH, STR, GROUP=group

IF N_ELEMENTS(Group) EQ 0 THEN Group = 0

Str_label  = CW_LABELNRH (GROUP= Group)

LABEL = CRE_LABELNRH( Str, Str_label)

RETURN, Label

END