;+ ***********************************************************************
; NAME:
;	CP_FLUXPOS_NRH2
;
; PURPOSE:
;	Cette fonction calcule le flux d'une position a un temps donne
;
; CATEGORY:
;	RH_2D, recherche de positions
;
; CALLING SEQUENCE:
;	flux = CP_FLUXPOS_NRH2(Str_gaus, Rayon, Freq, Npx, Npy)
;
; INPUTS:
;	Str_gaus:	struture decrivant le volume gaussien
;	Rayon:		rayon solaire
;	Freq:		frequence
;	Npx, Npy:	nombres de pixels en x et y
;
; OUTPUTS:
;	flux	valeur du flux pour le volume gaussien Str_gaus
;
; EXAMPLE:
;	Please provide a simple example here
;
; MODIFICATION HISTORY:
;	Ecrit par: C. Renie Sept. 1998
;-*******************************************************************

FUNCTION CP_FLUXPOS_NRH2, str_gauss, rayon, freq, dimx, dimy

	domega = FLOAT(16*3E-4/rayon)^2
	k = 0.136	;formule k=1.36e-23, pour avoir en SFU : K*e+22
	lamda = 300.0/freq
	
	volgaus = FLTARR(dimx, dimy)
	calc_volgauss, str_gauss, dimx, dimy, volgaus

	RETURN, TOTAL(volgaus)*2.0*k*domega/lamda^2

END
