;+ ***********************************************************************
; NAME: DEF_STR_DP
;	
; PURPOSE:
;       Initialisation par defaut d'une structure contenant tous les arguments
;	  d'appel de  RH_DPATCHFITS_NRH.
; 	
; CATEGORY:
;	Traitement de fichiers NRH.
;
; CALLING SEQUENCE:
;	
; INPUTS:
;  
; OUTPUTS:
;   str_dp  : structure contenant ces parametres a leur valeur par defaut.
;
; MODIFICATION HISTORY:
; 01 oct    : ecrit par: A. Bouteille
; 02 mar  5 : - ajout de sel_ant dans la liste d'entree pour eliminer les 
;		  antennes a problemes.
; 02 mar  7 : - ajout de crit_arret, larg_2 devient un fltarr(2).
;	 27 : - ajout de rot_p . 
; 03 jun 24 : - ajout des parametres de recalibration
;	    : - ----------------------- complement du pave central (recentrage)
; 03 sep 17 : ajout de :
;		. i_corr_pos_ant, i_source_cal, h_cal,
;	      retrait de : calib_np_p
; 04 jan 19 : - ajout de rh_common.inc    pour utiliser entfi.nbant
; 05 fev  9 : - ajout de  phi_w_e  a la liste d'entree.
; 06 mar  3 : - ajout de une dimension sipplementaire (2) a phi_ew_ns, phi_w_e,
;		   g_amp, g_phi pour pouvoir corriger manuellement et simulta-
;		   nement non polar et polar.
;	      - ajout de  i_affich_lobe et  i_mul_pol  dans la structure de 
;		  sortie..
; 06 jun  2 : Modif de  a_in,  a_ex,  larg_2,  coeff_seuil,  car la version
;		widgetisee ignore les valeurs definies dans  RH_DPNEW  et prend
;		celles definies dans  DEF_STR_DP.
;	      Jusqu'au 2 juin on avait  a_in=0.83,  a_ex=1.15, larg_2=[20, 30],
;		itermax = 400,  gain_iter=0.3
;
;-*******************************************************************

PRO DEF_STR_DP,	str_dp
				
; Mettre a jour str_dp  a chaque nouvelle version.

    str_dp  =  {version		: 'dpnew4.0'	,		$
		i_simulation	: 0		, 		$
		t_integ		: -1.		,		$
                n_period	: 1.		,		$
                mode_interpol	: 1		,		$
		rot_p		: 1		,		$
                np		: 128		,		$
                larg		: 4.0		,		$
                t_b		: 2		,		$
                i_affich_lobe	: 0		,		$
                i_mul_pol	: 1		,		$

                ie0_ew  	: 1		,		$
	        ie0_ns		: 0		,		$
                ie1_ew		: 1		,		$
                ie2_ew		: 1		,		$
                ie2_ns		: 1		,		$
                ins45_ew	: 1		,		$
                ins45_ns	: 1		,		$
		i_redond	: 0		,		$
                gap_ns0		: intarr (2)	,		$
		sel_ant		: intarr (48)	,		$

		i_con_cal	: 0		,		$

		i_corr_pos_ant	: 1		,		$
                i_recalib	: 0		,		$
                i_source_cal	: 1		,		$
		h_cal 		: [20, 00]	,		$	
		ch_cor		: ' '		,		$

		phi_ew_ns	: [0, 0]		,	$
		phi_w_e		: [0, 0]		,	$
		i_corr_g	: 0			,	$
		g_flag 		: replicate (0  , 48)	,	$
		g_amp 		: replicate (1.0, 48, 2),	$
		g_phi 		: replicate (0  , 48, 2),	$

                i_pave_plein	: 0		,		$
		i_recentrage	: 1		,		$
		x_centrage	: 0		,		$
		y_centrage	: 0		,		$

                mode_clean	: 0		,		$
                x_dom		: 0.		,		$
                y_dom		: 0.		,		$
                dr_dom		: 1.		,		$
                i_ech_min	: 0		,		$
                i_ech_max	: 3		,		$
                a_in		: 2.0 / 3	,		$
                a_ex		: 4.0 / 3	,		$
                a_red_fil	: 1.		,		$
                itermax		: 1000		,		$
                gain_iter	: 0.2		,		$
                jmax		: 2,				$
                crit_arret	: [1, 1, 1, 0,   0, 0, 0],	$
                i_seuil		: [1,  1,  1,  1,  2],		$
                i_test_arret	: 0		,		$
                i_stop_image	: 0		,		$
                i_ecrete	: intarr(4)	,		$
                frac_ecr	: fltarr(4)	,		$
                tete_fich	: ' '		,		$
                fac_crois_res	: 1.2		,		$
                coeff_seuil0	: fltarr(5)	,		$
                coeff_seuil1	: fltarr(5)	,		$
                coeff_seuil2	: fltarr(5)	,		$
                frac_flux	: 0.001		,		$
                i_lissage	: 2		,		$
                poids_c		: 0.7		,		$
                larg_2		: [18, 25]			$
                }
    str_dp.sel_ant(*) = 1               ; toutes les antennes sont presentes
                                        ;  au depart
    coeff_seuil = fltarr(3, 5)		; coeff_seuil(0, *) est inutilise.

	    ; Idem pour mode_clean = 1 ou 2 puisqu'on nettoie partout.
	    ; Le coeff usuel en fin de ligne est 0.0001 . Ajuster ce coeff pour
	    ;   que le nbre d'iterations soit entre 150 et 500.
	    ; Le 1er indice de coeff_seuil correspond a i_seuil. Usuellement on
	    ;   n'utilise donc que coeff_seuil(1, 0) et coeff_seuil(2, 1:3) .
    coeff_seuil(1, *) = [  4,  40,  80, 100, 100] * 0.0001 * 4.0 ; val max
    coeff_seuil(2, *) = [  5, 120, 200, 200, 350] * 0.0010 * 1.0 ; val rms
;  Valeurs en usage (pour la version widgetisee seule) jusqu'au 2 juin 2006
;   coeff_seuil(1, *) = [  3,  30,  40,  70, 100] * 0.0010  ; val max
;   coeff_seuil(2, *) = [100, 100, 200, 200, 200] * 0.0010  ; val rms

    str_dp.coeff_seuil0 = coeff_seuil(0,*)
    str_dp.coeff_seuil1 = coeff_seuil(1,*)
    str_dp.coeff_seuil2 = coeff_seuil(2,*)
;
    if (str_dp.mode_clean eq 0) then str_dp.jmax =  1	; bidon 
    if (str_dp.mode_clean eq 1) then str_dp.jmax =  2	; nbre d'iterations 
							;   d'affilee.
    if (str_dp.mode_clean eq 2) then str_dp.jmax =  2
    if (str_dp.mode_clean ge 3) then str_dp.jmax =  5

    end
