PRO RH_MOD_HEADER, dsmf, date, imstd, imstf, mmin, mmax, $
                    NBRE_ENRGT = nbre_enrgt
;+ ***********************************************************************
; NAME:
;	RH_MOD_HEADER
; PURPOSE:
;	Cette procedure met a jour les headers FITS primaire et d'extension
;	 apres ecriture des lignes.
; CATEGORY:
;	Traitement de fichiers NRH
; INPUTS:
;	dsmf	: nom du fichier
;	date	: date
;	imstd	: heure de debut
;	imstf	: heure de fin
;	mmin	: minimum des points
;	mmax	: maximum des points
; KEYWORD:
;  NBRE_ENRGT   : pour reajuster NAXIS2 nb effectif de lignes remplies
; MODIFICATION HISTORY:
;	Ecrit par A. Bouteille
;       06-10-2004 : mot cle NBRE_ENRGT
;-**************************************************************************

; La valeur de NAXIS2 doit etre connue et ecrite au FXBCREATE qui reserve
	; la place pour toutes les lignes
; Neanmoins pour les fichiers composites GMRT + RH, le nbre d'enrgts est
;  plus difficile a calculer a l'avance, les derniers enrgts du
;  fichier reserves au depart ne sont pas remplis. a fonction MRDFITS
;  se plante avec un ACCESS ERROR
; Pour resoudre ce probleme, il faut ajuster NAXIS2 au nbre de lignes
; effectivement remplies.

    IF N_ELEMENTS(nbre_enrgt) NE 0 THEN BEGIN 
        FXHMODIFY, dsmf, 'NAXIS2  ', nbre_enrgt, 'number of rows ', $
                   extension= 1 
    ENDIF
	; heures  
    chtime = RH_HDR_TIME(date, imstd)
    FXHMODIFY, dsmf, 'DATE_OBS', chtime,'   '

    ctime = MSH(imstd)
    FXHMODIFY, dsmf, 'TIM_STR', ctime,'   ', extension = 1

    chtime = RH_HDR_TIME (date, imstf)
    FXHMODIFY, dsmf, 'DATE_END',chtime,'   '

    ctime = MSH(imstf)
    FXHMODIFY, dsmf, 'TIM_END',ctime,'   ', extension = 1
    FXHMODIFY, dsmf,'TRVAL1  ',imstd,'   ', extension = 1

; Valeur max et valeur min
    fxhmodify, dsmf, 'DATAMIN ',mmin,'   ', extension = 1
    fxhmodify, dsmf, 'DATAMAX ',mmax,'   ', extension = 1

    end 		; fin de RH_MOD_HEADER.
