PRO RH_CALC_DOM_C, 				     $
	mode_clean,  x_dom,  y_dom,  dr_dom,	     $	; entree
	npi, maille, 				     $	; entree 
	dom_c						; sortie

; But :
;   Calculer le tableau dom_c des indices des points de l'image interferometri-
;     que du le domaine sur lequel on restitue (ou non) les composantes clean
;     (suivant les valeurs de mode_clean, voir plus bas).
;   L'image interferometrique est ici limitee a une seule periode (la periodi-
;     disation n'intervient qu'apres le clean).
;   Le domaine dom_c est un disque sur l'image heliographique, centr'e en
;     (x_dom, y_dom) et de rayon dr_dom (x_dom, y_dom, dr_dom en RS).

; Notations
; maille	[x0, y0, x1, y1, x2, y2] coord des points M0 (r=0, s=0), 
;		  M1 (r=1, s=0) et M2 (r=0, s=1), definissant la maille inter-
;		  ferometrique elementaire MI. 
; mode_clean	choix du mode de clean :
;		  . 0 pas de clean 
;		  . 1 pour clean normal sur champ entier,
;		  . 2 pour chercher partout les comp clean mais ne pas resti-
;			tuer celles interieures au domaine dom_c defini par 
;			x_dom, y_dom et dr_dom.
;		  . 3 pour retirer les composantes clean de dom_c et obtenir 
;			une image residuelle non nettoyee du reste.
; x_dom, y_dom	coord (RS, >0 ou <0) centre du domaine de clean.
; dr_dom,	rayon (RS) du domaine de clean.
; dom_c		tableau des indices de l'image interferometrique du domaine de
;		    clean,
; npi		dimension de l'image interferometrique (npi * npi)

   if (mode_clean eq 1) then begin
	dom_c = lindgen(long(npi)*long(npi))
    endif
    if ((mode_clean eq 2) or (mode_clean eq 3) or (mode_clean eq 4)) then begin
	    ;	i et j  indices heliographiques de -npi/2 a +npi/2-1
	    ;	X et Y les coord helio du pt (i, j)
	    ;	X = x0 + i*(x1 - x0) + j*(x2-x0)
	    ;	Y = y0 + i*(y1 - y0) + j*(y2-y0)
	x0 = maille(0)
	y0 = maille(1)
	x1 = maille(2)
	y1 = maille(3)
	x2 = maille(4)
	y2 = maille(5)

;     Construction des matrices mx et my des abscisses et ordonnees interfero-
	    ; metriques des points de l'image interferometrique (ici reduite a
	    ; une periode, la periodisation n'intervenant qu'apres le clean)
	v1 = indgen(npi)
	v2 = replicate(1, npi)	
	mx = v1 # v2
	my = transpose(mx)
	mx = mx - npi/2
	my = my - npi/2

;     Construction de la matrice dist_c des distances heliographiques (en RS) 
	    ; entre les points de la grille interferometrique et le centre de 
	    ; dom_c
	distx  = x0 + mx*(x1 - x0) + my*(x2 - x0) - x_dom
	disty  = y0 + mx*(y1 - y0) + my*(y2 - y0) - y_dom
	dist_c = sqrt (distx^2 + disty^2)

;     Definition du domaine dom_c	***
	dom_c  = where(dist_c lt dr_dom)

    endif

;     Controle
	icon = 0
	if (icon eq 1) then begin
	    print, 'RH_CALC_DOM_C :'
	    print, 'x_dom,  y_dom,  dr_dom, :',  x_dom,  y_dom,  dr_dom
	    toto = intarr(npi, npi)
	    toto(dom_c) = 1
;	  Trace des axes et du cadre
	    toto_512 = congrid(toto, 512, 512, cubic=-0.5)
	    toto_512(*, 510) = 1
	    toto_512(510, *) = 1
	    toto_512(*, 256) = 1
	    toto_512(256, *) = 1
	    window, 0	& wset, 0
	    shade_surf, toto
	    window, 1	& wset, 1
	    tvscl, toto_512
	    stop
	endif



    end			; fin de RH_CALC_DOM_C
