
FUNCTION RH_INTER_FFT,  af, np2		; entree
					; sortie af2

; But : interpolation par fft
;       Interpolation d'une fonction 1-D ou 2-D de np a np2 points. Les champs
;       de af et af2 sont respectivement:
;	. (1 - 1/np ) * periode
;	. (1 - 1/np2) * periode

; Procedures appelantes : RH_CALC_IMAGE_HELIO.

    taille = size(af)
    n_dim = taille(0)			; nbre de dimensions.
    nx = taille(1)
    if (n_dim eq 2) then  begin
	ny = taille(2)
	if (nx ne ny) then begin
	    print, 'RH_INTER_FFT : tableau en entree non carre'
	    stop
	endif
    endif
    np = nx			; dimension initiale
    if (np2 lt np) then begin
	print, 'RH_INTER_FFT : dimension demandee < dimension initiale'
	stop
    endif

; Calcul de la TF
	; Rappel 1 : par souci d'homogeneite on prend les memes conventions que
	;   RH_MALC_IM_2D pour le signe des TF:
	;   . fft directe (drapeau -1) pour passer de la visibilite a l'image,
	;   . --- inverse -------- +1  -------------- l'image a la visibilite.
	; Rappel 2:
	;   . la TF directe    comporte     un facteur 1/N
	;   . ----- inverse ne -------- pas --------------
    tf = fft(af, 1)		; fft inverse (ne comporte pas de facteur 1/N)

; Cas a une dimension
    if (n_dim eq 1) then begin
	tf2_c = complexarr(np2)
	tf_c  = shift(tf, np/2)				; centrage.
	tf2_c(np2/2 - np/2) = tf_c			; immersion centree.
	tf2 = shift(tf2_c, -np2/2)
	af2 = float(fft(tf2, -1)) * np2/np		; normalisation.
    endif

; Cas a deux dimensions
    if (n_dim eq 2) then begin
	tf2_c = complexarr(np2, np2)
	tf_c  = shift(tf, np/2, np/2)			; centrage.
	tf2_c(np2/2 - np/2,   np2/2 - np/2) = tf_c	; immersion centree.
	tf2 = shift(tf2_c, -np2/2, -np2/2)
	af2 = float(fft(tf2, -1))
	toto = where(abs(af2) lt 0.00001)
;	print, toto
	af2 = af2 * (np2/np)^2		; normalisation.
    endif

; Controle
    icon = 0
    if (icon eq 1) then begin
	if (n_dim eq 1) then begin
	endif
	if (n_dim eq 2) then begin
	    af_512  = congrid(af , 512, 512, cubic=-0.5)
	    af2_512 = congrid(af2, 512, 512, cubic=-0.5)
	    window, 0 	&	wset, 0
	    shade_surf, af_512
	    window, 1 	&	wset, 1
	    shade_surf, af2_512
	endif
	stop
    endif

    return, af2
    end			; fin de RH_INTER_FFT.
    
    


;______________________________________________________________________________


; Vesion d'essai
PRO INTER, np

; Definition fonction ce depart, lobe ponctuel sur 8 pts 9-4 a +3) centre en 0.
    x  = findgen(8) / 8
    af = float([0.8, 0, 0, 0, 1, 0, 0, 0]) + 0.1

; Interpolation
    tf_1 = fft(af, 1)
    tf_2 = complexarr(np)
    tf_2(0) = tf_1				; immersion dans grand tableau.
    af_2 = float(fft(tf_2, -1))
    plot, float(af_2)


    stop
    end
