
;+ ***********************************************************************
; NAME:
;	TIME_IND
;
; PURPOSE:
;	Recherche de l'indice correspondant a un temps donne dans un tableau de;  temps
;
; CATEGORY:
;	NRH 2D
;
; CALLING SEQUENCE:
;	IND = TIME_IND(Time, val)
;
; INPUTS:
;	TIME	tableau de temps en ms
;	VAL	Valeur du temps cherche en ms
;
; OUTPUTS:
;	IND indice dans le tableau
;		ERREUR si IND= -1, Temps non trouve, ou TIME n'est pas un
; tableau a 1 dimension	
;
; EXAMPLE:
;	data = MRDFITS('Fichier',1,Header)
;	temps = hms('10:30:50:80')
;	IND= TIME_IND(data.tempms,temps)
; donne l'indice de l'image correspondant a 11h,30mn,50s,80 centieme)
;	data(ind).np est le tableau correspondant au prametre de STOKES I
;	data(ind).p est le tableau correspondant au prametre de STOKES V
;
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin le 21/10/97
;		Le 04/06/99 conversion des heures en entier(JB)
;-*******************************************************************

FUNCTION TIME_IND,Time, val

       lim = size (time)
            if lim(1) le 1 THEN return,-1 
      i=0

 While i lt lim(1) DO BEGIN
       IF (time[i]) ge Val THEN return,i
       i = i+1
  END

Return, -1

END