
;+ ***********************************************************************
; NAME:
;	NRH_PLOTI
;
; PURPOSE:
;	Cette procedure trace l'ensemble des flux des fichiers de routine
;	Elle ne prend que N dernieres valeurs (KEYWORD NPOINTS)
;	Fichiers traites: nrin*.fts, nrot*.fts.
;	La boucle et l'enregistrement dans un fichier *.png sont geres par
;	WD_NRH_ROUT 
;
; CATEGORY:
;	NRH Routine
;
; CALLING SEQUENCE:
;	NRHR_PLOTI, [Ret], [Header], [Flux]
;
; INPUTS:
;
;	
; KEYWORD PARAMETERS:
;	FILE	Nom du fichier. Par defaut le fichier lu est le dernier
;		fichier present dans le repertoire indique
;	REPERT	Nom du repertoire
;	NPOINTS	Nombre de valeurs prises a partir de la fin du fichier
;
; OUTPUTS:
;	HEADER	Header 1 du fichier lu
;	FLUX	Tableau de flux lu
;	RET     Si ret = -1 le fichier cherche n'a pas etet trouve	
;
; OPTIONAL OUTPUTS:
;	
; COMMON BLOCKS:
;	
;
; SIDE EFFECTS:
;	Si le fichier indique n'est pas present la procedure envoie 
;	le message 'NO File found', et retourne 
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; EXAMPLE:
;
; MODIFICATION HISTORY:
;	Ecrit par:Jean.Bonmartin@obspm.fr
;	Ajustement des niveaux pour donnees calibrees le 07/11/01(JB
;-*******************************************************************

PRO nrhr_ploti, Ret, hd, Spec, FILE = File, NPOINTS=Npoints, REPERT= Repert 

IF NOT KEYWORD_SET(NPOINTS) THEN Npoints = 200

IF NOT KEYWORD_SET(REPERT) THEN Repert=''

IF NOT KEYWORD_SET (FILE) THEN BEGIN
;	CALDAT,SYSTIME(/JULIAN), Mois, Jour, An
;		Can = STRCOMPRESS(STRING(An),/REMOVE_ALL)
;		Cjour =STRING(Jour,FORMAT='(i2.2)')
;		Cmois = STRING(mois,FORMAT='(i2.2)')
;   FILTRE = 'nrin_'+Can+Cmois+Cjour+'_????????.fts'

;	LFile = FINDFILE(Repert+Filtre,COUNT=Count)

;	LFile = FINDFILE(Repert+Filtre,COUNT=Count)
;	IF Count EQ 0 THEN BEGIN
;		print,'No file found'
;		RET= -1
;		RETURN & END
  RET= 0
;  FILE=Lfile(Count-1)
	FILE = Repert+'sefram.fts'
ENDIF

H0 = HEADFITS(File)

HD = HEADFITS(File,EXTEN=1)
NVAL= FXPAR(HD, 'NAXIS2')
IF NVAL GT Npoints THEN IDEB= Nval-Npoints $
     ELSE IDEB =0

SPEC = MRDFITS (File, 1, RANGE=[Ideb , Nval-1],/SILENT)
NFREQ = FXPAR( H0, 'NFREQ')

NRH_COLOR_PLOT,RED=R, GREEN=G, BLUE=B, COLOR=Color, /ROUT
FREQ= FXPAR(H0, 'FREQ0')

IF FXPAR(HEADFITS(File),'CALIB') EQ 1 THEN BEGIN
		YRANGE=[1000.,10.^8] & YLOG=0
	ENDIF ELSE BEGIN
		YRANGE=[0.1,5] & YLOG=1
	ENDELSE

TR_TIME_NRH, Spec.Frq[0],Spec.time,YLOG=Ylog,YRANGE=Yrange,$
		CLAB=STRCOMPRESS(STRING(Freq),/REMOVE_ALL)+'MHz', $
		BACKGROUND=1, COLOR=0
FOR I= 1, NFREQ-1 DO BEGIN
	Linestyle=i
	NFreq = 'FREQ'+STRCOMPRESS(String(I),/REMOVE_ALL)
		Freq= FXPAR(H0, Nfreq)
	TR_TIME_NRH, Spec.Frq[i], Spec.time, /YLOG,/OPLOT,LINESTYLE=linestyle,$
		CLAB=STRCOMPRESS(STRING(Freq),/REMOVE_ALL)+'MHz', $
		BACKGROUND=1, COLOR=1
ENDFOR

;TVLCT,R,G,B	;restitution de l'ancienne table de couleurs

END
